#!/bin/sh
PROJECT_NAME=gtkdatabox
rm $PROJECT_NAME*.tar.gz
rm -r */.deps
cd pack
./nanogen.sh
cd ..
echo $PWD
MAJOR=0
MINOR=7
MICRO=`cat pack/micro`
NANO=`cat pack/nano`

RELEASE=$MAJOR.$MINOR.$MICRO
CURRENT=$NANO
VERSION=$RELEASE.$CURRENT

sed -e "s/##VERSION##/$VERSION/;\
        s/##LT_CURRENT##/$CURRENT/;\
        s/##LT_RELEASE##/$RELEASE/" pack/configure.ac.pre > configure.ac

sed -e "s/##VERSION##/$VERSION/;\
        s/##LT_CURRENT##/$CURRENT/;\
        s/##LT_RELEASE##/$RELEASE/" pack/gtkdatabox.pc.in.pre > gtkdatabox.pc.in

sed -e "s/##VERSION##/$VERSION/;\
        s/##LT_CURRENT##/$CURRENT/;\
        s/##LT_RELEASE##/$RELEASE/" pack/gtkdatabox.spec.pre > gtkdatabox.spec

pack/myAutoreconf.sh
make distcheck

